@@ -33,43 +33,42 @@
 #include <gconf/gconf-client.h>
 
 #include "get.h"
-#include "display.h"
-#include "mp.h"
+#include "register.h"
+#include "mpmath.h"
 
 #define EQUAL(a, b)    (strlen(a)==strlen(b)) & !strcmp(a, b) 
 
 /* Various string values read/written as X resources. */
 
-char *Rbstr[MAXBASES]     = { "BIN", "OCT", "DEC", "HEX" };
-char *Rdstr[MAXDISPMODES] = { "ENG", "FIX", "SCI" };
-char *Rmstr[MAXMODES]     = { "BASIC", "ADVANCED", "FINANCIAL", 
-                              "SCIENTIFIC" };
-char *Rtstr[MAXTRIGMODES] = { "DEG", "GRAD", "RAD" };
-char *Rsstr[MAXSYNTAX]    = { "ARITHMETIC", "ARITHMETIC_PRECEDENCE" };
+const char *Rbstr[MAXBASES]     = { "BIN", "OCT", "DEC", "HEX" };
+const char *Rdstr[MAXDISPMODES] = { "ENG", "FIX", "SCI" };
+const char *Rmstr[MAXMODES]     = { "BASIC", "ADVANCED", "FINANCIAL", 
+                                    "SCIENTIFIC", "PROGRAMMING" };
+const char *Rtstr[MAXTRIGMODES] = { "DEG", "GRAD", "RAD" };
 
 static GConfClient *client = NULL;
 
 
 char *
-get_resource(char *key)
+get_resource(const char *key)
 {
     char key_name[MAXLINE];
-    SNPRINTF(key_name, MAXLINE, "/apps/%s/%s", v->appname, key);
+    SNPRINTF(key_name, MAXLINE, "/apps/gcalctool/%s", key);
     return(gconf_client_get_string(client, key_name, NULL));
 }
 
 
 void
-set_resource(char *key, char *value)
+set_resource(const char *key, const char *value)
 {
     char key_name[MAXLINE];
-    SNPRINTF(key_name, MAXLINE, "/apps/%s/%s", v->appname, key);    
+    SNPRINTF(key_name, MAXLINE, "/apps/gcalctool/%s", key);    
     gconf_client_set_string(client, key_name, value, NULL);
 }
 
 
 void
-set_int_resource(char *key, int value)
+set_int_resource(const char *key, int value)
 {
     char intvalue[MAXLINE];
     SNPRINTF(intvalue, MAXLINE, "%d", value);
@@ -78,7 +77,7 @@ set_int_resource(char *key, int value)
 
 
 void
-set_boolean_resource(char *key, int value)
+set_boolean_resource(const char *key, int value)
 {
     if (value) {
         set_resource(key, "true");
@@ -89,7 +88,7 @@ set_boolean_resource(char *key, int value)
 
 
 char *
-convert(char *line)       /* Convert .gcalctoolcf line to ascii values. */
+convert(const char *line)       /* Convert .gcalctoolcf line to ascii values. */
 {
     static char output[MAXLINE];   /* Converted output record. */
     int i;                  /* Position within input line. */
@@ -111,7 +110,7 @@ convert(char *line)       /* Convert .gcalctoolcf line to ascii values. */
 
 
 int
-get_boolean_resource(char *key, int *boolval)
+get_boolean_resource(const char *key, int *boolval)
 {
     char *val, tempstr[MAXLINE];
     int len, n;
@@ -141,7 +140,7 @@ get_boolean_resource(char *key, int *boolval)
 /* Get integer resource from database. */
 
 int
-get_int_resource(char *key, int *intval)
+get_int_resource(const char *key, int *intval)
 {
     char *val;
  
@@ -163,7 +162,7 @@ get_int_resource(char *key, int *intval)
 const char *
 get_radix()
 {
-    char *radix;
+    const char *radix;
 
     setlocale(LC_NUMERIC, "");
     if ((radix = nl_langinfo(RADIXCHAR)) != NULL) {
@@ -181,7 +180,7 @@ get_radix()
 /* Get a string resource from database. */
 
 static int
-get_str_resource(char *key, char *strval)
+get_str_resource(const char *key, char *strval)
 {
     char *val;
     int i, len;
@@ -218,13 +217,20 @@ get_tsep()
     }
 
     if (tsep == NULL) {
-        return(",");
+        return("");
     } else {
         return(tsep);
     }
 }
 
 
+int
+get_tsep_count()
+{
+    return 3;
+}
+
+
 void
 read_resources()    /* Read all possible resources from the database. */
 {
@@ -234,6 +240,8 @@ read_resources()    /* Read all possible resources from the database. */
     if (get_int_resource(R_ACCURACY, &intval)) {
         v->accuracy = intval;
         if (v->accuracy < 0 || v->accuracy > MAXACC) {
+            /* Translators: A log message displayed when an invalid accuracy
+               is read from the configuration */
             FPRINTF(stderr, _("%s: accuracy should be in the range 0-%d\n"), 
                     v->progname, MAXACC);
             v->accuracy = 9;
@@ -243,7 +251,9 @@ read_resources()    /* Read all possible resources from the database. */
     for (i = 0; i < MAX_REGISTERS; i++) {
         SNPRINTF(key, MAXLINE, "register%d", i);
         if (get_str_resource(key, str)) {
-            MPstr_to_num(str, DEC, v->MPmvals[i]);
+            int temp[MP_SIZE];
+            MPstr_to_num(str, 10, temp);
+            register_set(i, temp);
         }
     }
 
@@ -255,6 +265,8 @@ read_resources()    /* Read all possible resources from the database. */
         }
 
         if (i == MAXBASES) {
+            /* Translators: A log message displayed when an invalid
+               base is read from the configuration */            
             FPRINTF(stderr, _("%s: base should be 2, 8, 10 or 16\n"), 
                     v->progname);
         } else {
@@ -270,6 +282,8 @@ read_resources()    /* Read all possible resources from the database. */
         }
 
         if (i == MAXDISPMODES) {
+            /* Translators: A log message displayed when an invalid
+               display mode is read from the configuration */
             FPRINTF(stderr, _("%s: invalid display mode [%s]\n"), 
                     v->progname, str);
         } else {
@@ -285,6 +299,8 @@ read_resources()    /* Read all possible resources from the database. */
         }
 
         if (i == MAXMODES) {
+            /* Translators: This message is a log message displayed when
+               an invalid mode is read from the configuration */            
             FPRINTF(stderr, _("%s: invalid mode [%s]\n"), v->progname, str);
         } else {
             v->modetype = (enum mode_type) i;
@@ -299,6 +315,8 @@ read_resources()    /* Read all possible resources from the database. */
         }
        
         if (i == MAXTRIGMODES) {
+            /* Translators: This message is a log message displayed when
+               an invalid trigonometric mode is read from the configuration */
             FPRINTF(stderr, _("%s: invalid trigonometric mode [%s]\n"), 
                     v->progname, str);
         } else {
@@ -306,24 +324,6 @@ read_resources()    /* Read all possible resources from the database. */
         }
     }
 
-    /* Set expression (arithmetic precedence) mode as default. */
-    v->syntax = EXPRS;
-
-    if (get_str_resource(R_SYNTAX, str)) {
-        for (i = 0; i < MAXSYNTAX; i++) {
-            if (EQUAL(str, Rsstr[i])) {
-                break;
-            }
-        }
-
-        if (i == MAXSYNTAX) {
-            FPRINTF(stderr, _("%s: invalid syntax mode [%s]\n"), 
-                    v->progname, str);
-        } else {
-            v->syntax = i;
-        }
-    }
-
     if (get_boolean_resource(R_ZEROES, &boolval)) {
         v->show_zeroes = boolval;
     }
@@ -333,29 +333,10 @@ read_resources()    /* Read all possible resources from the database. */
     }
 }
 
-
-void
-read_str(char **str, char *value)
-{
-    if (*str != NULL) {
-        (void) free(*str);
-    }
-    if (value != NULL && strlen(value)) {
-        *str = (char *) malloc((unsigned) (strlen(value) + 1));
-        STRCPY(*str, value);
-    } else {
-        *str = NULL;
-    }
-}
-
-
 void
 resources_init()        /* Load gconf configuration database for gcalctool. */
 { 
-    char str[MAXLINE];
-
     assert(client == NULL);
-    SNPRINTF(str, MAXLINE, "/apps/%s", v->appname);
     client = gconf_client_get_default();
-    gconf_client_add_dir(client, str, GCONF_CLIENT_PRELOAD_NONE, NULL);
+    gconf_client_add_dir(client, "/apps/gcalctool", GCONF_CLIENT_PRELOAD_NONE, NULL);
 }
